'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _sourceMapSupport2 = require('source-map-support');

exports.default = debug;

var _vm = require('vm');

var _vm2 = _interopRequireDefault(_vm);

var _repl = require('repl');

var _repl2 = _interopRequireDefault(_repl);

var _wdioLogger = require('wdio-logger');

var _wdioLogger2 = _interopRequireDefault(_wdioLogger);

var _wdioConfig = require('wdio-config');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _sourceMapSupport2.install)();
/**
 *
 * This command helps you to debug your integration tests. It stops the running browser and gives
 * you time to jump into it and check the state of your application (e.g. using dev tools).
 * Your terminal transforms into a [REPL](https://en.wikipedia.org/wiki/Read%E2%80%93eval%E2%80%93print_loop)
 * interface that will allow you to try out certain commands, find elements and test actions on
 * them.
 *
 * [![WebdriverIO REPL](http://webdriver.io/images/repl.gif)](http://webdriver.io/images/repl.gif)
 *
 * If you run the WDIO testrunner make sure you increase the timeout property of the test framework
 * you are using (e.g. Mocha or Jasmine) in order to prevent test termination due to a test timeout.
 * Also avoid executing the command with multiple capabilities running at the same time.
 *
 * <iframe width="560" height="315" src="https://www.youtube.com/embed/xWwP-3B_YyE" frameborder="0" allowfullscreen></iframe>
 *
 * <example>
    :debug.js
    it('should demonstrate the debug command', function () {
        browser.setValue('#input', 'FOO')
        browser.debug() // jumping into the browser and change value of #input to 'BAR'
        const value = browser.getValue('#input')
        console.log(value) // outputs: "BAR"
    })
 * </example>
 *
 * @alias browser.debug
 * @type utility
 *
 */

function debug() {
    var _this = this;

    var commandTimeout = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 5000;

    var log = (0, _wdioLogger2.default)('debug');
    _wdioLogger2.default.setLevel('debug', 1);

    log.debug(`The execution has stopped!`);
    log.debug(`You can now go into the browser or use the command line as REPL`);
    log.debug(`(To exit, press ^C again or type .exit)\n`);

    var commandIsRunning = false;

    /* istanbul ignore next */
    var myEval = function myEval(cmd, context, filename, callback) {
        if (commandIsRunning) {
            return;
        }

        if (cmd === 'browser\n') {
            return callback(null, '[WebdriverIO REPL client]');
        }

        commandIsRunning = true;
        var result = void 0;
        if (_wdioConfig.hasWdioSyncSupport) {
            return (0, _wdioConfig.runFnInFiberContext)(function () {
                try {
                    result = _vm2.default.runInThisContext(cmd);
                } catch (e) {
                    commandIsRunning = false;
                    return callback(e);
                }

                callback(null, result);
                commandIsRunning = false;
            })();
        }

        context.browser = _this;
        try {
            result = _vm2.default.runInThisContext(cmd);
        } catch (e) {
            commandIsRunning = false;
            return callback(e);
        }

        if (!result || typeof result.then !== 'function') {
            commandIsRunning = false;
            return callback(null, result);
        }

        var timeout = setTimeout(function () {
            return callback(new Error('Command execution timed out'));
        }, commandTimeout);
        result.then(function (res) {
            commandIsRunning = false;
            clearTimeout(timeout);
            return callback(null, res);
        }, function (e) {
            commandIsRunning = false;
            clearTimeout(timeout);
            var commandError = new Error(e.message);
            delete commandError.stack;
            return callback(commandError);
        });
    };

    var replServer = _repl2.default.start({
        prompt: '> ',
        eval: myEval,
        input: process.stdin,
        output: process.stdout,
        useGlobal: true,
        ignoreUndefined: true
    });

    return new _promise2.default(function (resolve) {
        return replServer.on('exit', resolve);
    });
}
module.exports = exports['default'];