'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _sourceMapSupport2 = require('source-map-support');

exports.default = keys;

var _utils = require('../../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _sourceMapSupport2.install)(); /**
                                    *
                                    * Send a sequence of key strokes to the active element. You can also use characters like
                                    * "Left arrow" or "Back space". WebdriverIO will take care of translating them into unicode
                                    * characters. You’ll find all supported characters [here](https://w3c.github.io/webdriver/webdriver-spec.html#keyboard-actions).
                                    * To do that, the value has to correspond to a key from the table.
                                    *
                                    * <example>
                                       :keys.js
                                       it('copies text out of active element', () => {
                                           // copies text from an input element
                                           const input = $('#username')
                                           input.setValue('anonymous')
                                   
                                           browser.keys(['Meta', 'a'])
                                           browser.keys(['Meta', 'c'])
                                       });
                                    * </example>
                                    *
                                    * @param {String|String[]} value  The sequence of keys to type. An array or string must be provided.
                                    * @see https://w3c.github.io/webdriver/#dispatching-actions
                                    *
                                    */

function keys(value) {
    var _this = this;

    var keySequence = [];

    /**
     * replace key with corresponding unicode character
     */
    if (typeof value === 'string') {
        keySequence = (0, _utils.checkUnicode)(value);
    } else if (value instanceof Array) {
        var _iteratorNormalCompletion = true;
        var _didIteratorError = false;
        var _iteratorError = undefined;

        try {
            for (var _iterator = (0, _getIterator3.default)(value), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
                var charSet = _step.value;

                keySequence = keySequence.concat((0, _utils.checkUnicode)(charSet));
            }
        } catch (err) {
            _didIteratorError = true;
            _iteratorError = err;
        } finally {
            try {
                if (!_iteratorNormalCompletion && _iterator.return) {
                    _iterator.return();
                }
            } finally {
                if (_didIteratorError) {
                    throw _iteratorError;
                }
            }
        }
    } else {
        throw new Error(`"keys" command requires an string or array of strings as parameter`);
    }

    /**
     * JsonWireProtocol action
     */
    if (!this.isW3C) {
        return this.sendKeys(keySequence);
    }

    /**
     * W3C way of handle it key actions
     */
    var keyDownActions = keySequence.map(function (value) {
        return { type: 'keyDown', value };
    });
    var keyUpActions = keySequence.map(function (value) {
        return { type: 'keyUp', value };
    });

    return this.performActions([{
        type: 'key',
        id: 'keyboard',
        actions: [].concat((0, _toConsumableArray3.default)(keyDownActions), (0, _toConsumableArray3.default)(keyUpActions))
    }]).then(function () {
        return _this.releaseActions();
    });
}
module.exports = exports['default'];