'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _sourceMapSupport2 = require('source-map-support');

var _newWindow = require('../../scripts/newWindow');

var _newWindow2 = _interopRequireDefault(_newWindow);

var _utils = require('../../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _sourceMapSupport2.install)();
/**
 *
 * Open new window in browser. This command is the equivalent function to `window.open()`. This command does not
 * work in mobile environments.
 *
 * __Note:__ When calling this command you automatically switch to the new window.
 *
 * <example>
    :newWindowSync.js
    it('should open a new tab', function () {
        browser.url('http://google.com')
        console.log(browser.getTitle()); // outputs: "Google"
        browser.newWindow('http://webdriver.io', 'WebdriverIO window', 'width=420,height=230,resizable,scrollbars=yes,status=1')
        console.log(browser.getTitle()); // outputs: "WebdriverIO - WebDriver bindings for Node.js"
        browser.close()
        console.log(browser.getTitle()); // outputs: "Google"
    });
 * </example>
 *
 * @param {String} url            website URL to open
 * @param {String} windowName     name of the new window
 * @param {String} windowFeatures features of opened window (e.g. size, position, scrollbars, etc.)
 * @return {String}                id of window handle of new tab
 *
 * @uses browser/execute, protocol/getWindowHandles, protocol/switchToWindow
 * @alias browser.newWindow
 * @type window
 */

exports.default = function () {
    var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(url) {
        var windowName = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'New Window';
        var windowFeatures = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';

        var _mobileDetector, isMobile, tabs, newTab;

        return _regenerator2.default.wrap(function _callee$(_context) {
            while (1) {
                switch (_context.prev = _context.next) {
                    case 0:
                        if (!(typeof url !== 'string')) {
                            _context.next = 2;
                            break;
                        }

                        throw new Error('number or type of arguments don\'t agree with newWindow command');

                    case 2:

                        /*!
                         * mobile check
                         */
                        _mobileDetector = (0, _utils.mobileDetector)(this.capabilities), isMobile = _mobileDetector.isMobile;

                        if (!isMobile) {
                            _context.next = 5;
                            break;
                        }

                        throw new Error('newWindow command is not supported on mobile platforms');

                    case 5:
                        _context.next = 7;
                        return this.execute(_newWindow2.default, url, windowName, windowFeatures);

                    case 7:
                        _context.next = 9;
                        return this.getWindowHandles();

                    case 9:
                        tabs = _context.sent;
                        newTab = tabs.pop();
                        _context.next = 13;
                        return this.switchToWindow(newTab);

                    case 13:
                        return _context.abrupt('return', newTab);

                    case 14:
                    case 'end':
                        return _context.stop();
                }
            }
        }, _callee, this);
    }));

    function newWindow(_x) {
        return _ref.apply(this, arguments);
    }

    return newWindow;
}();

module.exports = exports['default'];