'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _sourceMapSupport2 = require('source-map-support');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _sourceMapSupport2.install)();
/**
 *
 * Drag an item to a destination element.
 *
 * @alias browser.dragAndDrop
 * @param {Element} target    destination selector
 * @param {Number}  duration  how long the drag should take place
 * @uses action/moveToObject, protocol/buttonDown, protocol/buttonUp, property/getLocation, protocol/touchDown, protocol/touchMove, protocol/touchUp
 * @type action
 *
 */

var ACTION_BUTTON = 0;

exports.default = function () {
    var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(target) {
        var _this = this;

        var duration = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 100;
        var sourceRect, targetRect, sourceX, sourceY, targetX, targetY;
        return _regenerator2.default.wrap(function _callee$(_context) {
            while (1) {
                switch (_context.prev = _context.next) {
                    case 0:
                        if (!(!target || target.constructor.name !== 'Element')) {
                            _context.next = 2;
                            break;
                        }

                        throw new Error('command dragAndDrop requires an WebdriverIO Element as first parameter');

                    case 2:
                        if (this.isW3C) {
                            _context.next = 10;
                            break;
                        }

                        _context.next = 5;
                        return this.moveTo();

                    case 5:
                        _context.next = 7;
                        return this.buttonDown(ACTION_BUTTON);

                    case 7:
                        _context.next = 9;
                        return target.moveTo();

                    case 9:
                        return _context.abrupt('return', this.buttonUp(ACTION_BUTTON));

                    case 10:
                        _context.next = 12;
                        return this.getElementRect(this.elementId);

                    case 12:
                        sourceRect = _context.sent;
                        _context.next = 15;
                        return this.getElementRect(target.elementId);

                    case 15:
                        targetRect = _context.sent;
                        sourceX = parseInt(sourceRect.x + sourceRect.width / 2, 10);
                        sourceY = parseInt(sourceRect.y + sourceRect.height / 2, 10);
                        targetX = parseInt(targetRect.x + targetRect.width / 2, 10) - sourceX;
                        targetY = parseInt(targetRect.y + targetRect.height / 2, 10) - sourceY;

                        /**
                         * W3C way of handle the drag and drop action
                         */

                        return _context.abrupt('return', this.performActions([{
                            type: 'pointer',
                            id: 'finger1',
                            parameters: { pointerType: 'mouse' },
                            actions: [{ type: "pointerMove", duration: 0, x: sourceX, y: sourceY }, { type: "pointerDown", button: ACTION_BUTTON }, { type: "pause", duration: 10 }, // emulate human pause
                            { type: "pointerMove", duration, origin: "pointer", x: targetX, y: targetY }, { type: "pointerUp", button: ACTION_BUTTON }]
                        }]).then(function () {
                            return _this.releaseActions();
                        }));

                    case 21:
                    case 'end':
                        return _context.stop();
                }
            }
        }, _callee, this);
    }));

    function dragAndDrop(_x) {
        return _ref.apply(this, arguments);
    }

    return dragAndDrop;
}();

module.exports = exports['default'];