'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _sourceMapSupport2 = require('source-map-support');

var _utils = require('../../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _sourceMapSupport2.install)(); /**
                                    *
                                    * Get a css property from a DOM-element selected by given selector. The return value
                                    * is formatted to be testable. Colors gets parsed via [rgb2hex](https://www.npmjs.org/package/rgb2hex)
                                    * and all other properties get parsed via [css-value](https://www.npmjs.org/package/css-value).
                                    *
                                    * Note that shorthand CSS properties (e.g. background, font, border, margin, padding, list-style, outline,
                                    * pause, cue) are not returned, in accordance with the DOM CSS2 specification - you should directly access
                                    * the longhand properties (e.g. background-color) to access the desired values.
                                    *
                                    * <example>
                                       :example.html
                                       <label id="myLabel" for="input" style="color: #0088cc; font-family: helvetica, arial, freesans, clean, sans-serif, width: 100px">Some Label</label>
                                       :getCssProperty.js
                                       it('should demonstrate the getCssProperty command', function () {
                                           var elem = $('#myLabel')
                                           var color = elem.getCssProperty('color')
                                           console.log(color)
                                           // outputs the following:
                                           // {
                                           //     property: 'color',
                                           //     value: 'rgba(0, 136, 204, 1)',
                                           //     parsed: {
                                           //         hex: '#0088cc',
                                           //         alpha: 1,
                                           //         type: 'color',
                                           //         rgba: 'rgba(0, 136, 204, 1)'
                                           //     }
                                           // }
                                           var font = elem.getCssProperty('font-family')
                                           console.log(font)
                                           // outputs the following:
                                           // {
                                           //      property: 'font-family',
                                           //      value: 'helvetica',
                                           //      parsed: {
                                           //          value: [ 'helvetica', 'arial', 'freesans', 'clean', 'sans-serif' ],
                                           //          type: 'font',
                                           //          string: 'helvetica, arial, freesans, clean, sans-serif'
                                           //      }
                                           // }
                                           var width = elem.getCssProperty('width')
                                           console.log(width)
                                           // outputs the following:
                                           // {
                                           //     property: 'width',
                                           //     value: '100px',
                                           //     parsed: {
                                           //         type: 'number',
                                           //         string: '100px',
                                           //         unit: 'px',
                                           //         value: 100
                                           //     }
                                           // }
                                       })
                                    * </example>
                                    *
                                    * @alias browser.getCssProperty
                                    * @param {String} selector    element with requested style attribute
                                    * @param {String} cssProperty css property name
                                    * @uses protocol/elements, protocol/elementIdCssProperty
                                    * @type property
                                    *
                                    */

exports.default = function () {
    var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(cssProperty) {
        var cssValue;
        return _regenerator2.default.wrap(function _callee$(_context) {
            while (1) {
                switch (_context.prev = _context.next) {
                    case 0:
                        _context.next = 2;
                        return this.getElementCSSValue(this.elementId, cssProperty);

                    case 2:
                        cssValue = _context.sent;
                        return _context.abrupt('return', (0, _utils.parseCSS)(cssValue, cssProperty));

                    case 4:
                    case 'end':
                        return _context.stop();
                }
            }
        }, _callee, this);
    }));

    function getCSSProperty(_x) {
        return _ref.apply(this, arguments);
    }

    return getCSSProperty;
}();

module.exports = exports['default'];