'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _sourceMapSupport2 = require('source-map-support');

exports.default = getHTML;

var _constants = require('../../constants');

var _utils = require('../../utils');

var _getHTML = require('../../scripts/getHTML');

var _getHTML2 = _interopRequireDefault(_getHTML);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _sourceMapSupport2.install)(); /**
                                    *
                                    * Get source code of specified DOM element by selector.
                                    *
                                    * <example>
                                       :index.html
                                       <div id="test">
                                           <span>Lorem ipsum dolor amet</span>
                                       </div>
                                       :getHTML.js
                                       it('should get html for certain elements', function () {
                                           var outerHTML = browser.getHTML('#test');
                                           console.log(outerHTML);
                                           // outputs:
                                           // "<div id="test"><span>Lorem ipsum dolor amet</span></div>"
                                           var innerHTML = browser.getHTML('#test', false);
                                           console.log(innerHTML);
                                           // outputs:
                                           // "<span>Lorem ipsum dolor amet</span>"
                                       });
                                    * </example>
                                    *
                                    * @alias browser.getHTML
                                    * @param {String}   selector           element to get the current DOM structure from
                                    * @param {Boolean=} includeSelectorTag if true it includes the selector element tag (default: true)
                                    * @uses action/selectorExecute
                                    * @type property
                                    *
                                    */

function getHTML() {
    var includeSelectorTag = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

    return (0, _utils.getBrowserObject)(this).execute(_getHTML2.default, {
        [_constants.ELEMENT_KEY]: this.elementId, // w3c compatible
        ELEMENT: this.elementId // jsonwp compatible
    }, includeSelectorTag);
}
module.exports = exports['default'];