'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _sourceMapSupport2 = require('source-map-support');

exports.default = isDisplayedInViewport;

var _constants = require('../../constants');

var _utils = require('../../utils');

var _isDisplayedInViewport = require('../../scripts/isDisplayedInViewport');

var _isDisplayedInViewport2 = _interopRequireDefault(_isDisplayedInViewport);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _sourceMapSupport2.install)();
/**
 *
 * Return true if the selected DOM-element found by given selector is visible and within the viewport.
 *
 * <example>
    :index.html
    <div id="notDisplayed" style="display: none"></div>
    <div id="notVisible" style="visibility: hidden"></div>
    <div id="notInViewport" style="position:absolute; left: 9999999"></div>
    <div id="zeroOpacity" style="opacity: 0"></div>
    :isVisibleWithinViewport.js
    :isVisible.js
    it('should detect if an element is visible', function () {
        let isVisibleWithinViewport = browser.isVisibleWithinViewport('#notDisplayed');
        console.log(isVisibleWithinViewport); // outputs: false
        isVisibleWithinViewport = browser.isVisibleWithinViewport('#notVisible');
        console.log(isVisibleWithinViewport); // outputs: false
        isVisibleWithinViewport = browser.isVisibleWithinViewport('#notExisting');
        console.log(isVisibleWithinViewport); // outputs: false
        isVisibleWithinViewport = browser.isVisibleWithinViewport('#notInViewport');
        console.log(isVisibleWithinViewport); // outputs: false
        isVisibleWithinViewport = browser.isVisibleWithinViewport('#zeroOpacity');
        console.log(isVisibleWithinViewport); // outputs: false
    });
 * </example>
 *
 * @alias browser.isVisibleWithinViewport
 * @param   {String}             selector  DOM-element
 * @return {Boolean|Boolean[]}            true if element(s)* [is|are] visible
 * @uses protocol/selectorExecute, protocol/timeoutsAsyncScript
 * @type state
 *
 */

function isDisplayedInViewport() {
    return (0, _utils.getBrowserObject)(this).execute(_isDisplayedInViewport2.default, {
        [_constants.ELEMENT_KEY]: this.elementId, // w3c compatible
        ELEMENT: this.elementId // jsonwp compatible
    });
}
module.exports = exports['default'];