'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _sourceMapSupport2 = require('source-map-support');

exports.default = isFocused;

var _constants = require('../../constants');

var _utils = require('../../utils');

var _isFocused = require('../../scripts/isFocused');

var _isFocused2 = _interopRequireDefault(_isFocused);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _sourceMapSupport2.install)(); /**
                                    *
                                    * Return true or false if the selected DOM-element currently has focus. If the selector matches
                                    * multiple elements, it will return true if one of the elements has focus.
                                    *
                                    * <example>
                                       :index.html
                                       <input name="login" autofocus="" />
                                       :hasFocus.js
                                       it('should detect the focus of an element', function () {
                                           browser.url('/');
                                           const loginInput = $('[name="login"]');
                                           console.log(loginInput.hasFocus()); // outputs: false
                                           loginInput.click();
                                           console.log(loginInput.hasFocus()); // outputs: true
                                       })
                                    * </example>
                                    *
                                    * @alias browser.isFocused
                                    * @return {Boolean}         true if one of the matching elements has focus
                                    *
                                    * @uses protocol/execute
                                    * @type state
                                    *
                                    */

function isFocused() {
    return (0, _utils.getBrowserObject)(this).execute(_isFocused2.default, {
        [_constants.ELEMENT_KEY]: this.elementId, // w3c compatible
        ELEMENT: this.elementId // jsonwp compatible
    });
}
module.exports = exports['default'];