'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _sourceMapSupport2 = require('source-map-support');

exports.default = waitForVisible;
(0, _sourceMapSupport2.install)();

/**
 *
 * Wait for an element for the provided amount of
 * milliseconds to be (in)visible.
 *
 * <example>
    :index.html
    <div id="elem" style="visibility: hidden;">Hello World!</div>
    <script type="text/javascript">
        setTimeout(function () {
            document.getElementById('elem').style.visibility = 'visible';
        }, 2000);
    </script>
    :waitForVisibleExample.js
    it('should detect when element is visible', function () {
        const elem = $('#elem')
        elem.waitForVisible(3000);
    });
 * </example>
 *
 * @alias browser.waitForVisible
 * @param {Number=}  ms       time in ms (default: 500)
 * @param {Boolean=} reverse  if true it waits for the opposite (default: false)
 * @uses utility/waitUntil, state/isVisible
 * @type utility
 *
 */

function waitForVisible(ms) {
    var _this = this;

    var reverse = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

    /**
     * if element wasn't found in the first place wait for its existance first
     */
    if (!this.elementId && !reverse) {
        return this.waitForExist(ms).then(function () {
            return _this.waitForVisible(ms);
        });
    }

    /*!
     * ensure that ms is set properly
     */
    if (typeof ms !== 'number') {
        ms = this.options.waitforTimeout;
    }

    var isReversed = reverse ? '' : 'not';
    var errorMsg = `element ("${this.selector}") still ${isReversed} visible after ${ms}ms`;

    return this.waitUntil(function async() {
        return this.isElementDisplayed(this.elementId).then(function (isVisible) {
            return isVisible !== reverse;
        });
    }, ms, errorMsg);
}
module.exports = exports['default'];