'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.multiremote = exports.remote = undefined;

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _sourceMapSupport2 = require('source-map-support');

var _webdriver = require('webdriver');

var _webdriver2 = _interopRequireDefault(_webdriver);

var _wdioConfig = require('wdio-config');

var _constants = require('./constants');

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _sourceMapSupport2.install)();


/**
 * A method to create a new session with WebdriverIO
 *
 * @param  {Object} [params={}]       Options to create the session with
 * @param  {function} remoteModifier  Modifier function to change the monad object
 * @return {object}                   browser object with sessionId
 */
var remote = function remote() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var remoteModifier = arguments[1];

    var config = (0, _wdioConfig.validateConfig)(_constants.WDIO_DEFAULTS, params);
    var modifier = function modifier(client, options) {
        options = (0, _assign2.default)(options, config);

        if (typeof remoteModifier === 'function') {
            client = remoteModifier(client, options);
        }

        return client;
    };

    var prototype = (0, _utils.getPrototype)('browser');
    return _webdriver2.default.newSession(params, modifier, prototype, _wdioConfig.wrapCommand);
};

var multiremote = function multiremote() {
    /**
     * ToDo implement multiremote here
     */
    return 'NYI';
};

exports.remote = remote;
exports.multiremote = multiremote;