'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.elementErrorHandler = undefined;

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _sourceMapSupport2 = require('source-map-support');

var _wdioLogger = require('wdio-logger');

var _wdioLogger2 = _interopRequireDefault(_wdioLogger);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _sourceMapSupport2.install)();


var log = (0, _wdioLogger2.default)('webdriverio');

/**
 * This method is an command wrapper for elements that checks if a command is called
 * that wasn't found on the page and automatically waits for it
 *
 * @param  {Function} fn  commandWrap from wdio-sync package (or shim if not running in sync)
 */

/**
 * [elementErrorHandler description]

 * @return {[type]}      [description]
 */
var elementErrorHandler = exports.elementErrorHandler = function elementErrorHandler(fn) {
    return function (commandName, commandFn) {
        return function () {
            var _this = this;

            for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
                args[_key] = arguments[_key];
            }

            /**
             * wait on element if:
             *  - elementId couldn't be fetched in the first place
             *  - command is not explicit wait command for existance or displayedness
             */
            if (!this.elementId && !commandName.match(/(wait(Until|ForVisible|ForExist)|isExisting)/)) {
                log.debug(`command ${commandName} was called on an element ("${this.selector}") ` + `that wasn't found, waiting for it...`);

                return fn(commandName, function () {
                    /**
                     * create new promise so we can apply a custom error message in cases waitForExist fails
                     */
                    return new _promise2.default(function (resolve, reject) {
                        return _this.waitForExist().then(resolve, reject);
                    }).then(
                    /**
                     * if waitForExist was successful requery element and assign elementId to the scope
                     */
                    function () {
                        return _this.parent.$(_this.selector).then(function (elem) {
                            _this.elementId = elem.elementId;
                            return fn(commandName, commandFn).apply(_this, args);
                        });
                    },
                    /**
                     * if waitForExist failes throw custom error
                     */
                    function () {
                        throw new Error(`Can't call ${commandName} on element with selector "${_this.selector}" because element wasn't found`);
                    });
                }).apply(this);
            }

            return fn(commandName, commandFn).apply(this, args);
        };
    };
};