'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _sourceMapSupport2 = require('source-map-support');

exports.default = isDisplayedInViewport;
(0, _sourceMapSupport2.install)();
/**
 * check if element is visible and within the viewport
 * @param  {HTMLElement} elem  element to check
 * @return {Boolean}           true if element is within viewport
 */
function isDisplayedInViewport(elem) {
    var dde = document.documentElement;

    var isWithinViewport = true;
    while (elem.parentNode && elem.parentNode.getBoundingClientRect) {
        var elemDimension = elem.getBoundingClientRect();
        var elemComputedStyle = window.getComputedStyle(elem);
        var viewportDimension = {
            width: dde.clientWidth,
            height: dde.clientHeight
        };

        isWithinViewport = isWithinViewport && elemComputedStyle.display !== 'none' && elemComputedStyle.visibility === 'visible' && parseFloat(elemComputedStyle.opacity, 10) > 0 && elemDimension.bottom > 0 && elemDimension.right > 0 && elemDimension.top < viewportDimension.height && elemDimension.left < viewportDimension.width;

        elem = elem.parentNode;
    }

    return isWithinViewport;
}
module.exports = exports['default'];