'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.getElementFromResponse = exports.getPrototype = exports.findStrategy = undefined;

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _sourceMapSupport2 = require('source-map-support');

exports.mobileDetector = mobileDetector;
exports.getBrowserObject = getBrowserObject;
exports.transformToCharString = transformToCharString;
exports.parseCSS = parseCSS;
exports.checkUnicode = checkUnicode;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _cssValue = require('css-value');

var _cssValue2 = _interopRequireDefault(_cssValue);

var _rgb2hex = require('rgb2hex');

var _rgb2hex2 = _interopRequireDefault(_rgb2hex);

var _constants = require('./constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _sourceMapSupport2.install)();


var DEFAULT_SELECTOR = 'css selector';
var DIRECT_SELECTOR_REGEXP = /^(id|css selector|xpath|link text|partial link text|name|tag name|class name|-android uiautomator|-ios uiautomation|accessibility id):(.+)/;

var findStrategy = exports.findStrategy = function findStrategy(value, isW3C) {
    /**
     * set default selector
     */
    var using = DEFAULT_SELECTOR;

    if (typeof value !== 'string') {
        throw new Error('selector needs to be typeof `string`');
    }

    /**
     * check if user has specified locator strategy directly
     */
    var match = value.match(DIRECT_SELECTOR_REGEXP);
    if (match) {
        /**
         * ensure selector strategy is supported
         */
        if (isW3C && !_constants.W3C_SELECTOR_STRATEGIES.includes(match[1])) {
            throw new Error('InvalidSelectorStrategy'); // ToDo: move error to wdio-error package
        }

        return {
            using: match[1],
            value: match[2]
        };
    }

    // use xPath strategy if value starts with //
    if (value.indexOf('/') === 0 || value.indexOf('(') === 0 || value.indexOf('../') === 0 || value.indexOf('./') === 0 || value.indexOf('*/') === 0) {
        using = 'xpath';

        // use link text strategy if value startes with =
    } else if (value.indexOf('=') === 0) {
        using = 'link text';
        value = value.slice(1);

        // use partial link text strategy if value startes with *=
    } else if (value.indexOf('*=') === 0) {
        using = 'partial link text';
        value = value.slice(2);

        // recursive element search using the UiAutomator library (Android only)
    } else if (value.indexOf('android=') === 0) {
        using = '-android uiautomator';
        value = value.slice(8);

        // recursive element search using the UIAutomation library (iOS-only)
    } else if (value.indexOf('ios=') === 0) {
        using = '-ios uiautomation';
        value = value.slice(4);

        // recursive element search using accessibility id
    } else if (value.indexOf('~') === 0) {
        using = 'accessibility id';
        value = value.slice(1);

        // class name mobile selector
        // for iOS = UIA...
        // for Android = android.widget
    } else if (value.slice(0, 3) === 'UIA' || value.slice(0, 15) === 'XCUIElementType' || value.slice(0, 14).toLowerCase() === 'android.widget') {
        using = 'class name';

        // use tag name strategy if value contains a tag
        // e.g. "<div>" or "<div />"
    } else if (value.search(/<[a-zA-Z-]+( \/)*>/g) >= 0) {
        using = 'tag name';
        value = value.replace(/<|>|\/|\s/g, '');

        // use name strategy if value queries elements with name attributes
        // e.g. "[name='myName']" or '[name="myName"]'
    } else if (value.search(/^\[name=("|')([a-zA-z0-9\-_. ]+)("|')]$/) >= 0) {
        using = 'name';
        value = value.match(/^\[name=("|')([a-zA-z0-9\-_. ]+)("|')]$/)[2];

        // any element with given text e.g. h1=Welcome
    } else if (value.search(/^[a-z0-9]*=(.)+$/) >= 0) {
        var query = value.split(/=/);
        var tag = query.shift();

        using = 'xpath';
        value = `.//${tag.length ? tag : '*'}[normalize-space() = "${query.join('=')}"]`;

        // any element containing given text
    } else if (value.search(/^[a-z0-9]*\*=(.)+$/) >= 0) {
        var _query = value.split(/\*=/);
        var _tag = _query.shift();

        using = 'xpath';
        value = `.//${_tag.length ? _tag : '*'}[contains(., "${_query.join('*=')}")]`;

        // any element with certain class or id + given content
    } else if (value.search(/^[a-z0-9]*(\.|#)-?[_a-zA-Z]+[_a-zA-Z0-9-]*=(.)+$/) >= 0) {
        var _query2 = value.split(/=/);
        var _tag2 = _query2.shift();

        var classOrId = _tag2.substr(_tag2.search(/(\.|#)/), 1) === '#' ? 'id' : 'class';
        var classOrIdName = _tag2.slice(_tag2.search(/(\.|#)/) + 1);

        _tag2 = _tag2.substr(0, _tag2.search(/(\.|#)/));
        using = 'xpath';
        value = `.//${_tag2.length ? _tag2 : '*'}[contains(@${classOrId}, "${classOrIdName}") and normalize-space() = "${_query2.join('=')}"]`;

        // any element with certain class or id + has certain content
    } else if (value.search(/^[a-z0-9]*(\.|#)-?[_a-zA-Z]+[_a-zA-Z0-9-]*\*=(.)+$/) >= 0) {
        var _query3 = value.split(/\*=/);
        var _tag3 = _query3.shift();

        var _classOrId = _tag3.substr(_tag3.search(/(\.|#)/), 1) === '#' ? 'id' : 'class';
        var _classOrIdName = _tag3.slice(_tag3.search(/(\.|#)/) + 1);

        _tag3 = _tag3.substr(0, _tag3.search(/(\.|#)/));
        using = 'xpath';
        value = './/' + (_tag3.length ? _tag3 : '*') + '[contains(@' + _classOrId + ', "' + _classOrIdName + '") and contains(., "' + _query3.join('*=') + '")]';
        value = `.//${_tag3.length ? _tag3 : '*'}[contains(@${_classOrId}, "${_classOrIdName}") and contains(., "${_query3.join('*=')}")]`;

        // allow to move up to the parent or select current element
    } else if (value === '..' || value === '.') {
        using = 'xpath';
    }

    /**
     * ensure selector strategy is supported
     */
    if (isW3C && !_constants.W3C_SELECTOR_STRATEGIES.includes(using)) {
        throw new Error('InvalidSelectorStrategy'); // ToDo: move error to wdio-error package
    }

    return { using, value };
};

var applyScopePrototype = function applyScopePrototype(prototype, scope) {
    var dir = _path2.default.resolve(__dirname, 'commands', scope);
    var files = _fs2.default.readdirSync(dir);
    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
        for (var _iterator = (0, _getIterator3.default)(files), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
            var filename = _step.value;

            var commandName = _path2.default.basename(filename, _path2.default.extname(filename));
            prototype[commandName] = { value: require(_path2.default.join(dir, commandName)) };
        }
    } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
    } finally {
        try {
            if (!_iteratorNormalCompletion && _iterator.return) {
                _iterator.return();
            }
        } finally {
            if (_didIteratorError) {
                throw _iteratorError;
            }
        }
    }
};

/**
 * enhances objects with element commands
 */
var getPrototype = exports.getPrototype = function getPrototype(scope) {
    var prototype = {};

    /**
     * register action commands
     */
    applyScopePrototype(prototype, scope);
    return prototype;
};

/**
 * get element id from WebDriver response
 * @param  {object} res         body object from response
 * @return {string|undefined}   element id or null if element couldn't be found
 */
var getElementFromResponse = exports.getElementFromResponse = function getElementFromResponse(res) {
    /**
     * depcrecated JSONWireProtocol response
     */
    if (res.ELEMENT) {
        return res.ELEMENT;
    }

    /**
     * W3C WebDriver response
     */
    if (res[_constants.ELEMENT_KEY]) {
        return res[_constants.ELEMENT_KEY];
    }

    return null;
};

/**
 * check if current platform is mobile device
 *
 * @param  {Object}  caps  capabilities
 * @return {Boolean}       true if platform is mobile device
 */
function mobileDetector(caps) {
    var isMobile = Boolean(typeof caps['appium-version'] !== 'undefined' || typeof caps['device-type'] !== 'undefined' || typeof caps['deviceType'] !== 'undefined' || typeof caps['device-orientation'] !== 'undefined' || typeof caps['deviceOrientation'] !== 'undefined' || typeof caps.deviceName !== 'undefined' ||
    // Check browserName for specific values
    caps.browserName === '' || caps.browserName !== undefined && (caps.browserName.toLowerCase() === 'ipad' || caps.browserName.toLowerCase() === 'iphone' || caps.browserName.toLowerCase() === 'android'));

    var isIOS = Boolean(caps.platformName && caps.platformName.match(/iOS/i) || caps.deviceName && caps.deviceName.match(/(iPad|iPhone)/i));

    var isAndroid = Boolean(caps.platformName && caps.platformName.match(/Android/i) || caps.browserName && caps.browserName.match(/Android/i));

    return { isMobile, isIOS, isAndroid };
}

/**
 * traverse up the scope chain until browser element was reached
 */
function getBrowserObject(elem) {
    return elem.parent ? getBrowserObject(elem.parent) : elem;
}

/**
 * transform whatever value is into an array of char strings
 */
function transformToCharString(value) {
    var ret = [];

    if (!Array.isArray(value)) {
        value = [value];
    }

    var _iteratorNormalCompletion2 = true;
    var _didIteratorError2 = false;
    var _iteratorError2 = undefined;

    try {
        for (var _iterator2 = (0, _getIterator3.default)(value), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
            var val = _step2.value;

            if (typeof val === 'string') {
                ret.push.apply(ret, (0, _toConsumableArray3.default)(val.split('')));
            } else if (typeof val === 'number') {
                var entry = `${val}`.split('');
                ret.push.apply(ret, (0, _toConsumableArray3.default)(entry));
            } else if (val && typeof val === 'object') {
                try {
                    ret.push.apply(ret, (0, _toConsumableArray3.default)((0, _stringify2.default)(val).split('')));
                } catch (e) {/* ignore */}
            } else if (typeof val === 'boolean') {
                var _entry = val ? 'true'.split('') : 'false'.split('');
                ret.push.apply(ret, (0, _toConsumableArray3.default)(_entry));
            }
        }
    } catch (err) {
        _didIteratorError2 = true;
        _iteratorError2 = err;
    } finally {
        try {
            if (!_iteratorNormalCompletion2 && _iterator2.return) {
                _iterator2.return();
            }
        } finally {
            if (_didIteratorError2) {
                throw _iteratorError2;
            }
        }
    }

    return ret;
}

function sanitizeCSS(value) {
    /* istanbul ignore next */
    if (!value) {
        return value;
    }

    return value.trim().replace(/'/g, '').replace(/"/g, '').toLowerCase();
}

/**
 * parse css values to a better format
 * @param  {Object} cssPropertyValue result of WebDriver call
 * @param  {String} cssProperty      name of css property to parse
 * @return {Object}                  parsed css property
 */
function parseCSS(cssPropertyValue, cssProperty) {
    if (!cssPropertyValue) {
        return null;
    }

    var parsedValue = {
        property: cssProperty,
        value: cssPropertyValue.toLowerCase().trim()
    };

    if (parsedValue.value.indexOf('rgb') === 0) {
        /**
         * remove whitespaces in rgb values
         */
        parsedValue.value = parsedValue.value.replace(/\s/g, '');

        /**
         * parse color values
         */
        var color = parsedValue.value;
        parsedValue.parsed = (0, _rgb2hex2.default)(parsedValue.value);
        parsedValue.parsed.type = 'color';
        parsedValue.parsed[/[rgba]+/g.exec(color)[0]] = color;
    } else if (parsedValue.property === 'font-family') {
        var font = (0, _cssValue2.default)(cssPropertyValue);
        var string = parsedValue.value;
        var value = cssPropertyValue.split(/,/).map(sanitizeCSS);

        parsedValue.value = sanitizeCSS(font[0].value || font[0].string);
        parsedValue.parsed = { value, type: 'font', string };
    } else {
        /**
         * parse other css properties
         */
        try {
            parsedValue.parsed = (0, _cssValue2.default)(cssPropertyValue);

            if (parsedValue.parsed.length === 1) {
                parsedValue.parsed = parsedValue.parsed[0];
            }

            if (parsedValue.parsed.type && parsedValue.parsed.type === 'number' && parsedValue.parsed.unit === '') {
                parsedValue.value = parsedValue.parsed.value;
            }
        } catch (e) {
            // TODO improve css-parse lib to handle properties like
            // `-webkit-animation-timing-function :  cubic-bezier(0.25, 0.1, 0.25, 1)
        }
    }

    return parsedValue;
}

/**
 * check for unicode character or split string into literals
 * @param  {String} value  text
 * @return {Array}         set of characters or unicode symbols
 */
function checkUnicode(value) {
    return _constants.UNICODE_CHARACTERS.hasOwnProperty(value) ? [_constants.UNICODE_CHARACTERS[value]] : value.split('');
}